<?php
// wcf imports
require_once(WCF_DIR.'lib/data/message/bbcode/BBCodeParser.class.php');
require_once(WCF_DIR.'lib/data/message/bbcode/CodeBBCode.class.php');

/**
 * Parses the [php] bbcode tag, which highlights php source code using the internal function 'highlight_string'.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2009 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.data.message.bbcode.code
 * @subpackage	data.message.bbcode
 * @category 	Community Framework (commercial)
 */
class PHPCodeBBCode extends CodeBBCode {
	/**
	 * @see BBCode::getParsedTag()
	 */
	public function getParsedTag($openingTag, $content, $closingTag, BBCodeParser $parser) {
		if ($parser->getOutputType() == 'text/html') {	
			// add starting php tag
			$phpTagsAdded = false;
			$content = self::trim($content);
			if (StringUtil::indexOf($content, '<?') === false) {
				$phpTagsAdded = true;
				$content = '<?php '.$content.' ?>';
			}

			// do highlight
			$highlightedCode = highlight_string($content, true);
			
			// clear code
			$highlightedCode = str_replace('<code>', '', $highlightedCode);
			$highlightedCode = str_replace('</code>', '', $highlightedCode);

			// remove added php tags
			if ($phpTagsAdded) {
				$highlightedCode = preg_replace("/([^\\2]*)(&lt;\?php&nbsp;)(.*)(&nbsp;.*\?&gt;)([^\\4]*)/si", "\\1\\3\\5", $highlightedCode);
			}
			
			// remove breaks
			$highlightedCode = str_replace("\n", "", $highlightedCode);
			$highlightedCode = str_replace('<br />', "\n", $highlightedCode);
			
			// replace double quotes by entity
			//echo $highlightedCode."\n\n\n"; 
			$highlightedCode = preg_replace('/(?<!\<span style=)"(?!\>)/', '&quot;', $highlightedCode);
			//echo $highlightedCode; exit;
			// show template
			WCF::getTPL()->assign(array(
				'lineNumbers' => $this->makeLineNumbers($highlightedCode, $this->getLineNumbersStart($openingTag)),
				'content' => $highlightedCode,
				'codeBoxName' => WCF::getLanguage()->get('wcf.bbcode.php.title')
			));
			return WCF::getTPL()->fetch('codeBBCodeTag');
		}
		else if ($parser->getOutputType() == 'text/plain') {
			return WCF::getLanguage()->get('wcf.bbcode.code.text', array('$content' => $content));
		}
	}
}
?>